==> haskell-drbg-0.5.5-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-7QYKbXQ7r2IUJ27NMBre7
key:                  DRBG-0.5.5-7QYKbXQ7r2IUJ27NMBre7
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  c8351a3c36bb4b4af84c8dfa37705ef5
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-9.0.1/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/DRBG-0.5.5
hs-libraries:         HSDRBG-0.5.5-7QYKbXQ7r2IUJ27NMBre7
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7
    cipher-aes128-0.7.0.6-2metV9Clx0DGFpQp5tJICz
    crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    cryptohash-cryptoapi-0.1.4-HMNzMvLVvFQGHGhO9VY1l5
    entropy-0.4.1.7-66OkMQHXKESGwpio7bQXje mtl-2.2.2
    parallel-3.2.2.0-G9JTeCQCHda2yggytvFxi6
    prettyclass-1.0.0.0-FLpKvWUSyBT10zZio3rFtI
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-ASaSvtl5JHL7i3G6PWasev
key:                  DRBG-0.5.5-ASaSvtl5JHL7i3G6PWasev
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  7c41a6908db3d0b504943c5b4c3e0e64
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-9.0.1/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/DRBG-0.5.5
hs-libraries:         HSDRBG-0.5.5-ASaSvtl5JHL7i3G6PWasev
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7
    cipher-aes128-0.7.0.6-2metV9Clx0DGFpQp5tJICz
    crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    cryptohash-cryptoapi-0.1.4-8hQuxL2GtPeBSJvPzV9nif
    entropy-0.4.1.7-66OkMQHXKESGwpio7bQXje mtl-2.2.2
    parallel-3.2.2.0-G9JTeCQCHda2yggytvFxi6
    prettyclass-1.0.0.0-FLpKvWUSyBT10zZio3rFtI
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
